==> smart_ip-6.x-1.0-alpha1.tar.gz: smart_ip/modules/device_geolocation/theme/device-geolocation-visitor-info.tpl.php <==
<?php
// $Id: device-geolocation-visitor-info.tpl.php,v 1.2 2010/10/16 00:18:13 arpeggio Exp $

/**
 * @file device-geolocation-visitor-info.tpl.php
 * Default theme implementation for rendering user's geolocation details block.
 *
 * Available variables:
 * - $location: An associative array with possible array items:
 * -- latitude: May came from Smart IP or W3C Geolocation API or Google Gears
 * -- longitude: May came from Smart IP or W3C Geolocation API or Google Gears
 * -- street_number: Google Geocoder service specific item
 * -- postal_code: Google Geocoder service specific item
 * -- route: Google Geocoder service specific item
 * -- neighborhood: Google Geocoder service specific item
 * -- locality: Google Geocoder service specific item
 * -- sublocality: Google Geocoder service specific item
 * -- establishment: Google Geocoder service specific item
 * -- administrative_area_level_N: Google Geocoder service specific item
 * -- country: May came from Smart IP or Google Geocoder service
 * -- country_code: May came from Smart IP or Google Geocoder service
 * -- zip: Smart IP specific item
 * -- region: Smart IP specific item
 * -- region_code: Smart IP specific item
 *
 * @ingroup themeable
 */
?>
<dl>
  <?php foreach ($location as $item => $value): ?>
    <?php if (!empty($value) && $item != 'region_code'): ?>
      <?php
        $item = str_replace('_', ' ', $item);
        $item[0] = strtoupper($item[0]);
      ?>
      <dt><?php print $item; ?></dt>
      <dd><?php print $value; ?></dd>
    <?php endif; ?>
  <?php endforeach; ?>
</dl>

==> smart_ip-6.x-1.2-alpha1.tar.gz: smart_ip/modules/device_geolocation/theme/device-geolocation-visitor-info.tpl.php <==
<?php
// $Id: device-geolocation-visitor-info.tpl.php,v 1.3.2.2 2010/12/15 23:21:51 arpeggio Exp $

/**
 * @file device-geolocation-visitor-info.tpl.php
 * Default theme implementation for rendering user's geolocation details block.
 *
 * Available variables:
 * - $location: An associative array with possible array items:
 * -- latitude: May came from Smart IP or W3C Geolocation API or Google Gears
 * -- longitude: May came from Smart IP or W3C Geolocation API or Google Gears
 * -- street_number: Google Geocoder service specific item
 * -- postal_code: Google Geocoder service specific item
 * -- route: Google Geocoder service specific item
 * -- neighborhood: Google Geocoder service specific item
 * -- locality: Google Geocoder service specific item
 * -- sublocality: Google Geocoder service specific item
 * -- establishment: Google Geocoder service specific item
 * -- administrative_area_level_N: Google Geocoder service specific item
 * -- country: May came from Smart IP or Google Geocoder service
 * -- country_code: May came from Smart IP or Google Geocoder service
 * -- zip: Smart IP specific item
 * -- region: Smart IP specific item
 * -- region_code: Smart IP specific item
 * -- timestamp: Timestamp of these data stored
 *
 * @ingroup themeable
 */
?>
<dl>
  <?php foreach ($location as $item => $value): ?>
    <?php if (!empty($value) && $item != 'region_code' && $item != 'timestamp'): ?>
      <?php
        $item = str_replace('_', ' ', $item);
        $item[0] = strtoupper($item[0]);
      ?>
      <dt><?php print $item; ?></dt>
      <dd><?php print $value; ?></dd>
    <?php endif; ?>
  <?php endforeach; ?>
</dl>
